@@ -2,7 +2,9 @@
 #define LOG_H
 
 #include <stdio.h>
+#include <time.h>
 
+#include <sys/time.h>
 #include <sys/types.h>
 
 
@@ -16,10 +18,10 @@ void log_real_(pid_t tid, const char *tag, const char *format, ...);
 #define log_warn(i, s, ...) log_warn_(i, s "\n", ## __VA_ARGS__)
 #define log_info(i, s, ...) log_info_(i, s "\n", ## __VA_ARGS__)
 
-#define log_critical_(i, s, ...) log_real_(i, "Critical", s, ## __VA_ARGS__)
-#define log_error_(i, s, ...) log_real_(i, "Error", s, ## __VA_ARGS__)
-#define log_warn_(i, s, ...) log_real_(i, "Warning", s, ## __VA_ARGS__)
-#define log_info_(i, s, ...) log_real_(i, NULL, s, ## __VA_ARGS__)
+#define log_critical_(i, s, ...) log_real_(i, "CRITICAL", s, ## __VA_ARGS__)
+#define log_error_(i, s, ...) log_real_(i, "ERROR", s, ## __VA_ARGS__)
+#define log_warn_(i, s, ...) log_real_(i, "WARNING", s, ## __VA_ARGS__)
+#define log_info_(i, s, ...) log_real_(i, "INFO", s, ## __VA_ARGS__)
 
 #else
 
@@ -28,10 +30,10 @@ void log_real_(pid_t tid, const char *tag, const char *format, ...);
 #define log_warn(i, s, ...) log_warn_(i, s "\n", __VA_ARGS__)
 #define log_info(i, s, ...) log_info_(i, s "\n", __VA_ARGS__)
 
-#define log_critical_(i, s, ...) log_real_(i, "Critical", s, __VA_ARGS__)
-#define log_error_(i, s, ...) log_real_(i, "Error", s, __VA_ARGS__)
-#define log_warn_(i, s, ...) log_real_(i, "Warning", s, __VA_ARGS__)
-#define log_info_(i, s, ...) log_real_(i, NULL, s, __VA_ARGS__)
+#define log_critical_(i, s, ...) log_real_(i, "CRITICAL", s, __VA_ARGS__)
+#define log_error_(i, s, ...) log_real_(i, "ERROR", s, __VA_ARGS__)
+#define log_warn_(i, s, ...) log_real_(i, "WARNING", s, __VA_ARGS__)
+#define log_info_(i, s, ...) log_real_(i, "INFO", s, __VA_ARGS__)
 #endif
 
 #endif
